@@ -116,6 +116,9 @@ def _embed_cli(cfg, is_cli_call=True):
         path = os.path.join(os.getcwd(), 'embeddings.csv')
         save_embeddings(path, embeddings, labels, filenames)
         print(f'Embeddings are stored at {bcolors.OKBLUE}{path}{bcolors.ENDC}')
+        os.environ[
+            cfg['environment_variable_names']['lightly_last_embedding_path']
+        ] = path
         return path
 
     return embeddings, labels, filenames
